summaryrefslogtreecommitdiff
path: root/indra/newview/llspeakers.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llspeakers.h')
-rw-r--r--indra/newview/llspeakers.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/indra/newview/llspeakers.h b/indra/newview/llspeakers.h
index 55d2351cbf..1a8c23f56a 100644
--- a/indra/newview/llspeakers.h
+++ b/indra/newview/llspeakers.h
@@ -181,11 +181,11 @@ public:
* It based call moderateVoiceParticipant() for each avatar should be muted/unmuted.
*
* @param[in] excluded_avatar_id UUID of avatar NOT to be processed
* @param[in] unmute if true - avatars will be muted, otherwise - unmuted.
*
* @see moderateVoiceParticipant()
*/
- void moderateVoiceOtherParticipants(const LLUUID& excluded_avatar_id, bool unmute);
+ void moderateVoiceOtherParticipants(const LLUUID& excluded_avatar_id, bool unmute_everyone_else);
void processSessionUpdate(const LLSD& session_update);
@@ -181,11 +181,11 @@ public:
*
* @param[in] excluded_avatar_id UUID of avatar NOT to be processed
- * @param[in] unmute if true - avatars will be muted, otherwise - unmuted.
+ * @param[in] unmute_everyone_else if false - avatars will be muted, otherwise - unmuted.
*
* @see moderateVoiceParticipant()